summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTreehugger Robot <treehugger-gerrit@google.com>2023-05-30 19:19:21 +0000
committerAutomerger Merge Worker <android-build-automerger-merge-worker@system.gserviceaccount.com>2023-05-30 19:19:21 +0000
commitce93e250cfbe9d1e457aff451c8989e04f9e9739 (patch)
treec36386cd060aa90e9098fcb0b3883b0b3072041b
parent86774721bf071dd3757bc4683160627c9253e817 (diff)
parent9291e007b46d1a177ec197486bf9a22eae942ed3 (diff)
downloadmisc-ce93e250cfbe9d1e457aff451c8989e04f9e9739.tar.gz
Merge changes I4fdfe1bc,Id4a568dd,I4f116d6d,I25c49ffd,I5f8867f5, ... am: 9291e007b4
Original change: https://android-review.googlesource.com/c/platform/prebuilts/misc/+/2607057 Change-Id: I5133c1fee87e12c41b28e11adb341ec299fd0a4e Signed-off-by: Automerger Merge Worker <android-build-automerger-merge-worker@system.gserviceaccount.com>
-rw-r--r--common/androidx-media3/Android.bp70
-rw-r--r--common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2-sources.jarbin0 -> 56158 bytes
-rw-r--r--common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2.aarbin0 -> 73833 bytes
-rw-r--r--common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2.pom46
-rw-r--r--common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2-sources.jarbin0 -> 97003 bytes
-rw-r--r--common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2.aarbin0 -> 126199 bytes
-rw-r--r--common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2.pom53
-rw-r--r--common/androidx-media3/manifests/androidx.media3.media3-effect/AndroidManifest.xml24
-rw-r--r--common/androidx-media3/manifests/androidx.media3.media3-transformer/AndroidManifest.xml24
-rwxr-xr-xcommon/androidx-media3/update-from-gmaven.py4
10 files changed, 220 insertions, 1 deletions
diff --git a/common/androidx-media3/Android.bp b/common/androidx-media3/Android.bp
index cb1570a2..c6711c2b 100644
--- a/common/androidx-media3/Android.bp
+++ b/common/androidx-media3/Android.bp
@@ -150,6 +150,40 @@ android_library {
}
android_library_import {
+ name: "androidx.media3.media3-effect-nodeps",
+ aars: ["androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2.aar"],
+ sdk_version: "current",
+ apex_available: [
+ "//apex_available:platform",
+ "//apex_available:anyapex",
+ ],
+ min_sdk_version: "18",
+ static_libs: [
+ "androidx.annotation_annotation",
+ "androidx.media3.media3-common",
+ ],
+ visibility: ["//visibility:private"]
+}
+
+android_library {
+ name: "androidx.media3.media3-effect",
+ sdk_version: "current",
+ apex_available: [
+ "//apex_available:platform",
+ "//apex_available:anyapex",
+ ],
+ min_sdk_version: "18",
+ manifest: "manifests/androidx.media3.media3-effect/AndroidManifest.xml",
+ static_libs: [
+ "androidx.media3.media3-effect-nodeps",
+ "androidx.annotation_annotation",
+ "androidx.media3.media3-common",
+ ],
+ java_version: "1.7",
+ visibility: library_visibility
+}
+
+android_library_import {
name: "androidx.media3.media3-exoplayer-nodeps",
aars: ["androidx/media3/media3-exoplayer/1.0.2/media3-exoplayer-1.0.2.aar"],
sdk_version: "current",
@@ -266,6 +300,42 @@ android_library {
}
android_library_import {
+ name: "androidx.media3.media3-transformer-nodeps",
+ aars: ["androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2.aar"],
+ sdk_version: "current",
+ apex_available: [
+ "//apex_available:platform",
+ "//apex_available:anyapex",
+ ],
+ min_sdk_version: "21",
+ static_libs: [
+ "androidx.annotation_annotation",
+ "androidx.media3.media3-exoplayer",
+ "androidx.media3.media3-effect",
+ ],
+ visibility: ["//visibility:private"]
+}
+
+android_library {
+ name: "androidx.media3.media3-transformer",
+ sdk_version: "current",
+ apex_available: [
+ "//apex_available:platform",
+ "//apex_available:anyapex",
+ ],
+ min_sdk_version: "21",
+ manifest: "manifests/androidx.media3.media3-transformer/AndroidManifest.xml",
+ static_libs: [
+ "androidx.media3.media3-transformer-nodeps",
+ "androidx.annotation_annotation",
+ "androidx.media3.media3-exoplayer",
+ "androidx.media3.media3-effect",
+ ],
+ java_version: "1.7",
+ visibility: library_visibility
+}
+
+android_library_import {
name: "androidx.media3.media3-ui-nodeps",
aars: ["androidx/media3/media3-ui/1.0.2/media3-ui-1.0.2.aar"],
sdk_version: "current",
diff --git a/common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2-sources.jar b/common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2-sources.jar
new file mode 100644
index 00000000..c1d0c255
--- /dev/null
+++ b/common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2-sources.jar
Binary files differ
diff --git a/common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2.aar b/common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2.aar
new file mode 100644
index 00000000..6be86bf4
--- /dev/null
+++ b/common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2.aar
Binary files differ
diff --git a/common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2.pom b/common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2.pom
new file mode 100644
index 00000000..cab10718
--- /dev/null
+++ b/common/androidx-media3/androidx/media3/media3-effect/1.0.2/media3-effect-1.0.2.pom
@@ -0,0 +1,46 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<project xmlns="http://maven.apache.org/POM/4.0.0" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 https://maven.apache.org/xsd/maven-4.0.0.xsd" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
+ <!-- This module was also published with a richer model, Gradle metadata, -->
+ <!-- which should be used instead. Do not delete the following line which -->
+ <!-- is to indicate to Gradle or any Gradle module metadata file consumer -->
+ <!-- that they should prefer consuming it instead. -->
+ <!-- do_not_remove: published-with-gradle-metadata -->
+ <modelVersion>4.0.0</modelVersion>
+ <groupId>androidx.media3</groupId>
+ <artifactId>media3-effect</artifactId>
+ <version>1.0.2</version>
+ <packaging>aar</packaging>
+ <name>Media3 Effect module</name>
+ <description>Media3 Effect module</description>
+ <licenses>
+ <license>
+ <name>The Apache Software License, Version 2.0</name>
+ <url>http://www.apache.org/licenses/LICENSE-2.0.txt</url>
+ <distribution>repo</distribution>
+ </license>
+ </licenses>
+ <developers>
+ <developer>
+ <name>The Android Open Source Project</name>
+ </developer>
+ </developers>
+ <scm>
+ <connection>scm:git:https://github.com/androidx/media.git</connection>
+ <url>https://github.com/androidx/media</url>
+ </scm>
+ <dependencies>
+ <dependency>
+ <groupId>androidx.annotation</groupId>
+ <artifactId>annotation</artifactId>
+ <version>1.3.0</version>
+ <scope>runtime</scope>
+ </dependency>
+ <dependency>
+ <groupId>androidx.media3</groupId>
+ <artifactId>media3-common</artifactId>
+ <version>1.0.2</version>
+ <scope>runtime</scope>
+ <type>aar</type>
+ </dependency>
+ </dependencies>
+</project>
diff --git a/common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2-sources.jar b/common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2-sources.jar
new file mode 100644
index 00000000..b7a7f093
--- /dev/null
+++ b/common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2-sources.jar
Binary files differ
diff --git a/common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2.aar b/common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2.aar
new file mode 100644
index 00000000..6f51e3bb
--- /dev/null
+++ b/common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2.aar
Binary files differ
diff --git a/common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2.pom b/common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2.pom
new file mode 100644
index 00000000..af2eb151
--- /dev/null
+++ b/common/androidx-media3/androidx/media3/media3-transformer/1.0.2/media3-transformer-1.0.2.pom
@@ -0,0 +1,53 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<project xmlns="http://maven.apache.org/POM/4.0.0" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 https://maven.apache.org/xsd/maven-4.0.0.xsd" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
+ <!-- This module was also published with a richer model, Gradle metadata, -->
+ <!-- which should be used instead. Do not delete the following line which -->
+ <!-- is to indicate to Gradle or any Gradle module metadata file consumer -->
+ <!-- that they should prefer consuming it instead. -->
+ <!-- do_not_remove: published-with-gradle-metadata -->
+ <modelVersion>4.0.0</modelVersion>
+ <groupId>androidx.media3</groupId>
+ <artifactId>media3-transformer</artifactId>
+ <version>1.0.2</version>
+ <packaging>aar</packaging>
+ <name>Media3 Transformer module</name>
+ <description>Media3 Transformer module</description>
+ <licenses>
+ <license>
+ <name>The Apache Software License, Version 2.0</name>
+ <url>http://www.apache.org/licenses/LICENSE-2.0.txt</url>
+ <distribution>repo</distribution>
+ </license>
+ </licenses>
+ <developers>
+ <developer>
+ <name>The Android Open Source Project</name>
+ </developer>
+ </developers>
+ <scm>
+ <connection>scm:git:https://github.com/androidx/media.git</connection>
+ <url>https://github.com/androidx/media</url>
+ </scm>
+ <dependencies>
+ <dependency>
+ <groupId>androidx.annotation</groupId>
+ <artifactId>annotation</artifactId>
+ <version>1.3.0</version>
+ <scope>runtime</scope>
+ </dependency>
+ <dependency>
+ <groupId>androidx.media3</groupId>
+ <artifactId>media3-exoplayer</artifactId>
+ <version>1.0.2</version>
+ <scope>runtime</scope>
+ <type>aar</type>
+ </dependency>
+ <dependency>
+ <groupId>androidx.media3</groupId>
+ <artifactId>media3-effect</artifactId>
+ <version>1.0.2</version>
+ <scope>runtime</scope>
+ <type>aar</type>
+ </dependency>
+ </dependencies>
+</project>
diff --git a/common/androidx-media3/manifests/androidx.media3.media3-effect/AndroidManifest.xml b/common/androidx-media3/manifests/androidx.media3.media3-effect/AndroidManifest.xml
new file mode 100644
index 00000000..77209370
--- /dev/null
+++ b/common/androidx-media3/manifests/androidx.media3.media3-effect/AndroidManifest.xml
@@ -0,0 +1,24 @@
+<?xml version="1.0" encoding="utf-8"?>
+<!--
+ Copyright 2022 The Android Open Source Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
+<manifest xmlns:android="http://schemas.android.com/apk/res/android"
+ package="androidx.media3.effect" >
+
+ <uses-sdk
+ android:minSdkVersion="18"
+ android:targetSdkVersion="30" />
+
+</manifest> \ No newline at end of file
diff --git a/common/androidx-media3/manifests/androidx.media3.media3-transformer/AndroidManifest.xml b/common/androidx-media3/manifests/androidx.media3.media3-transformer/AndroidManifest.xml
new file mode 100644
index 00000000..902260fb
--- /dev/null
+++ b/common/androidx-media3/manifests/androidx.media3.media3-transformer/AndroidManifest.xml
@@ -0,0 +1,24 @@
+<?xml version="1.0" encoding="utf-8"?>
+<!--
+ Copyright 2020 The Android Open Source Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
+<manifest xmlns:android="http://schemas.android.com/apk/res/android"
+ package="androidx.media3.transformer" >
+
+ <uses-sdk
+ android:minSdkVersion="21"
+ android:targetSdkVersion="30" />
+
+</manifest> \ No newline at end of file
diff --git a/common/androidx-media3/update-from-gmaven.py b/common/androidx-media3/update-from-gmaven.py
index d1d0bf97..da903d5a 100755
--- a/common/androidx-media3/update-from-gmaven.py
+++ b/common/androidx-media3/update-from-gmaven.py
@@ -23,7 +23,7 @@
# Manual verification steps:
# 1. Build the 'leaf' imported modules (i.e. the set that ends up depending
# on *everything* transitively), e.g.
# $ m androidx.media3.media3-exoplayer androidx.media3.media3-session androidx.media3.media3-ui
import os
import subprocess
@@ -106,9 +106,11 @@ downloadArtifact("androidx.media3", "media3-common", media3Version)
downloadArtifact("androidx.media3", "media3-database", media3Version)
downloadArtifact("androidx.media3", "media3-datasource", media3Version)
downloadArtifact("androidx.media3", "media3-decoder", media3Version)
+downloadArtifact("androidx.media3", "media3-effect", media3Version)
downloadArtifact("androidx.media3", "media3-exoplayer", media3Version)
downloadArtifact("androidx.media3", "media3-extractor", media3Version)
downloadArtifact("androidx.media3", "media3-session", media3Version)
+downloadArtifact("androidx.media3", "media3-transformer", media3Version)
downloadArtifact("androidx.media3", "media3-ui", media3Version)
atxRewriteStr = ""
@@ -23,7 +23,7 @@
# 1. Build the 'leaf' imported modules (i.e. the set that ends up depending
# on *everything* transitively), e.g.
-# $ m androidx.media3.media3-exoplayer androidx.media3.media3-session androidx.media3.media3-ui
+# $ m androidx.media3.media3-exoplayer androidx.media3.media3-session androidx.media3.media3-transformer androidx.media3.media3-ui
import os
import subprocess